@@ -1,7 +1,10 @@
 package MooseX::Constructor::AllErrors::Role::Object;
+our $VERSION = '0.004';
+
 
 use Moose::Role;
-use Try::Tiny;
+use Moose::Util;
+use MooseX::Constructor::AllErrors::Error;
 
 my $new_error = sub { 
   my $class = shift;
@@ -18,7 +21,7 @@ around BUILDARGS => sub {
   });
 
   my $meta = Moose::Util::find_meta($self);
-  for my $attr (sort { $a->insertion_order <=> $b->insertion_order } $meta->get_all_attributes) {
+  for my $attr ($meta->compute_all_applicable_attributes) {
     next unless defined( my $init_arg = $attr->init_arg );
 
     if ($attr->is_required and 
@@ -32,22 +35,13 @@ around BUILDARGS => sub {
 
     next unless exists $args->{$init_arg} && $attr->has_type_constraint;
 
-    my $tc = $attr->type_constraint;
-    my $value = $tc->has_coercion && $attr->should_coerce
-        ? $tc->coerce($args->{$init_arg})
-        : $args->{$init_arg};
-
-    # use the attributes verify_against_type_constraint as that can be wrapped
-    # by other roles, namely MooseX::UndefTolerant
-    try {
-      $attr->verify_against_type_constraint($value);
-    }
-    catch {
+    unless ($attr->type_constraint->check($args->{$init_arg})) {
       $error->add_error($new_error->(TypeConstraint => {
         attribute => $attr,
-        data      => $value,
+        data      => $args->{$init_arg},
       }));
-    };
+      next;
+    }
   }
 
   if ($error->has_errors) {
